@@ -45,9 +45,7 @@
     self.tableView.separatorColor = [UIColor VLCDarkBackgroundColor];
     self.tableView.backgroundColor = [UIColor VLCDarkBackgroundColor];
 
-    if (SYSTEM_RUNS_IOS9_OR_LATER) {
-        self.dropboxTableViewController = [[VLCDropboxTableViewController alloc] initWithNibName:@"VLCCloudStorageTableViewController" bundle:nil];
-    }
+    self.dropboxTableViewController = [[VLCDropboxTableViewController alloc] initWithNibName:@"VLCCloudStorageTableViewController" bundle:nil];
     self.googleDriveTableViewController = [[VLCGoogleDriveTableViewController alloc] initWithNibName:@"VLCCloudStorageTableViewController" bundle:nil];
     [[VLCBoxController sharedInstance] startSession];
     self.boxTableViewController = [[VLCBoxTableViewController alloc] initWithNibName:@"VLCCloudStorageTableViewController" bundle:nil];
@@ -77,16 +75,7 @@
 
 - (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
 {
-    if (SYSTEM_RUNS_IOS9_OR_LATER) {
-        return 5;
-    }
-    // on iOS 8+ add document picker option, but keep Dropbox disabled
-    if ([UIDocumentPickerViewController class]) {
-        return 4;
-    }
-
-    // iOS 7, neither document picker nor Dropbox
-    return 3;
+    return @available(iOS 8.0, *) ? 5 : 4; // on iOS 8+ add document picker option
 }
 
 - (void)tableView:(UITableView *)tableView willDisplayCell:(UITableViewCell *)cell forRowAtIndexPath:(NSIndexPath *)indexPath
@@ -109,13 +98,7 @@
 - (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
 
     VLCCloudServiceCell *cell = [tableView dequeueReusableCellWithIdentifier:@"CloudServiceCell" forIndexPath:indexPath];
-    NSInteger row = indexPath.row;
-
-    if (!SYSTEM_RUNS_IOS9_OR_LATER) {
-        row++;
-    }
-
-    switch (row) {
+    switch (indexPath.row) {
         case 0: {
             //Dropbox
             BOOL isAuthorized = [[VLCDropboxController sharedInstance] isAuthorized];
@@ -167,23 +150,6 @@
 
 #pragma mark - Table view delegate
 
-- (NSIndexPath *)tableView:(UITableView *)tableView willSelectRowAtIndexPath:(NSIndexPath *)indexPath
-{
-    if (SYSTEM_RUNS_IOS8_OR_LATER) {
-        // don't let select CLOUD_DRIVES menu item since there is no view controller to reveal
-        if (indexPath.row == [self tableView:tableView numberOfRowsInSection:indexPath.section] - 1) {
-            [tableView deselectRowAtIndexPath:indexPath animated:YES];
-            if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad)
-                [self.documentPickerController showDocumentMenuViewController:[(VLCCloudServiceCell *)[self.tableView cellForRowAtIndexPath:indexPath] icon]];
-            else
-                [self.documentPickerController showDocumentMenuViewController:nil];
-
-            return nil;
-        }
-    }
-    return indexPath;
-}
-
 - (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
 {
     return 66.0;
@@ -191,13 +157,8 @@
 
 - (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
 {
-    NSInteger row = indexPath.row;
-
-    if (!SYSTEM_RUNS_IOS9_OR_LATER) {
-        row++;
-    }
-
-    switch (row) {
+    [tableView deselectRowAtIndexPath:indexPath animated:YES];
+    switch (indexPath.row) {
         case 0:
             //dropBox
             [self.navigationController pushViewController:self.dropboxTableViewController animated:YES];
@@ -214,7 +175,12 @@
             //OneDrive
             [self.navigationController pushViewController:self.oneDriveTableViewController animated:YES];
             break;
-
+        case 4:
+            if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad)
+                [self.documentPickerController showDocumentMenuViewController:[(VLCCloudServiceCell *)[self.tableView cellForRowAtIndexPath:indexPath] icon]];
+            else
+                [self.documentPickerController showDocumentMenuViewController:nil];
+            break;
         default:
             break;
     }
