@@ -146,6 +146,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
 
     if (!_collectionView) {
         _folderLayout = [[VLCFolderCollectionViewFlowLayout alloc] init];
+        _reorderLayout = [[LXReorderableCollectionViewFlowLayout alloc] init];
         _collectionView = [[UICollectionView alloc] initWithFrame:viewDimensions collectionViewLayout:_folderLayout];
         _collectionView.alwaysBounceVertical = YES;
         if (@available(iOS 11.0, *)) {
@@ -316,7 +317,8 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
                         if (recognizer == _folderLayout.panGestureRecognizer || recognizer == _folderLayout.longPressGestureRecognizer || recognizer == _longPressGestureRecognizer)
                             [self.collectionView removeGestureRecognizer:recognizer];
                     }
-                    _reorderLayout = [[LXReorderableCollectionViewFlowLayout alloc] init];
+                    //reloadData before setting a new layout avoids a crash deep in UIKits UICollectionViewData layoutattributs
+                    [self.collectionView reloadData];
                     [self.collectionView setCollectionViewLayout:_reorderLayout animated:NO];
                 }
             }
@@ -342,7 +344,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
 
 - (void)createSpotlightItem:(nonnull NSManagedObject *)mediaObject
 {
-    if ([CSSearchableItemAttributeSet class] != nil && ![VLCKeychainCoordinator passcodeLockEnabled]) {
+    if (@available(iOS 9.0, *) && ![VLCKeychainCoordinator passcodeLockEnabled]) {
         self.userActivity = [[NSUserActivity alloc] initWithActivityType:kVLCUserActivityPlaying];
 
         MLFile *file = nil;
@@ -1102,7 +1104,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
     NSArray *indexPaths = [self usingTableViewToShowData] ? [self.tableView indexPathsForSelectedRows] : [self.collectionView indexPathsForSelectedItems];
 
     if ((!indexPaths || [indexPaths count] == 0) && !_deleteFromTableView) {
-        if ([UIAlertController class]) {
+        if (@available(iOS 8, *)) {
             UIAlertController *invalidSelection = [UIAlertController alertControllerWithTitle:NSLocalizedString(@"DELETE_INVALID_TITLE", nil) message:NSLocalizedString(@"DELETE_INVALID_MESSAGE", nil) preferredStyle:UIAlertControllerStyleAlert];
             UIAlertAction *doneAction = [UIAlertAction actionWithTitle:NSLocalizedString(@"BUTTON_OK", nil) style:UIAlertActionStyleDefault handler:nil];
 
